==> crp_core-0.0.1.tar.gz: lib/core/provider/ApiGraphqlProvider.dart <==
import 'dart:io';

import 'package:crp_core/core/exception/AppException.dart';
import 'package:crp_core/core/model/Entity.dart';
import 'package:crp_core/core/provider/GraphqlQuery.dart';
import 'package:crp_core/core/provider/Provider.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

typedef S ClientGraphQLRequest<S>();

class ApiGraphqlProvider<T extends Entity> extends Provider<T> {
  final GraphQLClient _client;
  final GraphqlQuery _graphqlQuery;

  ApiGraphqlProvider(this._client, this._graphqlQuery)
      : assert(_client != null),
        assert(_graphqlQuery != null);

  @override
  Future<dynamic> fetchAll() async {
    return await fetch(() => _client.query(_graphqlQuery.fetchQuery()));
  }

  @override
  Future<dynamic> fetchById(int id) async {
    return await fetch(() => _client.query(_graphqlQuery.fetchQueryById(id)));
  }

  @override
  Future<dynamic> delete(int id) async {
    return await fetch(() => _client.mutate(_graphqlQuery.deleteMutation(id)));
  }

  @override
  Future<dynamic> update(T instance) async {
    return await fetch(
        () => _client.mutate(_graphqlQuery.updateMutation(instance)));
  }

  @override
  Future<dynamic> insert(T instance) async {
    return await fetch(
        () => _client.mutate(_graphqlQuery.insertMutation(instance)));
  }

  Future<dynamic> fetch(ClientGraphQLRequest request) async {
    try {
      QueryResult response = await request();
      if (!response.hasException) {
        return response.data[_graphqlQuery.getTableName()];
      } else {
        throw AppException(response.exception.toString(), "GraphQL");
      }
    } on SocketException {
      throw FetchDataException('Sem conexão à Internet');
    } catch (e) {
      throw AppException(e.toString(), "GraphQL");
    }
  }
}

==> crp_core-0.0.2.tar.gz: lib/core/provider/ApiGraphqlProvider.dart <==
import 'dart:io';

import 'package:crp_core/core/exception/AppException.dart';
import 'package:crp_core/core/model/Entity.dart';
import 'package:crp_core/core/provider/GraphqlQuery.dart';
import 'package:crp_core/core/provider/Provider.dart';
import 'package:graphql_flutter/graphql_flutter.dart';

typedef S ClientGraphQLRequest<S>();

class ApiGraphqlProvider<T extends Entity> extends Provider<T> {
  final GraphQLClient _client;
  final GraphqlQuery _graphqlQuery;

  ApiGraphqlProvider(this._client, this._graphqlQuery)
      : assert(_client != null),
        assert(_graphqlQuery != null);

  @override
  Future<dynamic> fetchAll() async {
    return await fetch(() => _client.query(_graphqlQuery.fetchQuery()));
  }

  @override
  Future<dynamic> fetchById(dynamic id) async {
    return await fetch(() => _client.query(_graphqlQuery.fetchQueryById(id)));
  }

  @override
  Future<dynamic> delete(dynamic id) async {
    return await fetch(() => _client.mutate(_graphqlQuery.deleteMutation(id)));
  }

  @override
  Future<dynamic> update(T instance) async {
    return await fetch(
        () => _client.mutate(_graphqlQuery.updateMutation(instance)));
  }

  @override
  Future<dynamic> insert(T instance) async {
    return await fetch(
        () => _client.mutate(_graphqlQuery.insertMutation(instance)));
  }

  Future<dynamic> fetch(ClientGraphQLRequest request) async {
    try {
      QueryResult response = await request();
      if (!response.hasException) {
        return response.data[_graphqlQuery.getTableName()];
      } else {
        throw AppException(response.exception.toString(), "GraphQL");
      }
    } on SocketException {
      throw FetchDataException('Sem conexão à Internet');
    } catch (e) {
      throw AppException(e.toString(), "GraphQL");
    }
  }
}
